/* 
 * This file is part of XRM.
 * Copyright (C) 2006  Benoit Sigoure.
 *
 * XRM is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

#ifndef LIBSTR_REALS_H_
# define LIBSTR_REALS_H_

# include <srts/stratego.h>

/**
** Transform an ATerm which is either an AT_REAL or an AT_INT into a double.
** @param dst destination double (itself, not a pointer to it)
** @param term term to transform in double.
** @warning the caller MUST ensure that @a term is of type AT_REAL or AT_INT.
*/
# define NUMERIC_ATERM_TO_REAL(dst, term)	\
  do {						\
    if(ATgetType(term) == AT_REAL)		\
    {						\
      dst = ATgetReal((ATermReal) term);	\
    }						\
    else /* (ATgetType(term) == AT_INT) */	\
    {						\
      dst = ATgetInt((ATermInt) term);		\
    }						\
  } while(0)

ATerm STR_REALS_ceil(ATerm t);
ATerm STR_REALS_floor(ATerm t);
ATerm STR_REALS_powi(ATerm base, ATerm power);
ATerm STR_REALS_powr(ATerm base, ATerm power);
ATerm STR_REALS_modi(ATerm lhs, ATerm rhs);
ATerm STR_REALS_modr(ATerm lhs, ATerm rhs);

#endif /* !LIBSTR_REALS_H_ */
