#! /bin/sh
# Installer for XRM that relocates a binary distribution.

test x"$1" = x && {
  echo 'Usage: install-xrm.sh <prefix>
Installs XRM under <prefix>.' >&2
  exit 1
}

me=`basename "$0"`
abort()
{
  echo "$me: $*." >&2
  exit 1
}

prefix=$1
DEFAULT_XTC_REPOS='share/xrm/XTC'
test -d "$prefix" || abort "'$prefix' is not a directory or doesn't exist"

case "$prefix" in
  [\\/]* | ?:[\\/]* ) # Absolute
     ;;
  *)
     abort "'$prefix' is not an absolute path"
     ;;
esac

my_dir=`dirname "$0"`
cd "$my_dir" || abort "$my_dir: No such directory"

echo '>>> Relocating XTC repositories'
for f in : `find share -type f -name XTC`; do
  test x"$f" = x: && continue
  echo -n "    $f"
  cp "$f" "$f.tmp" || abort "Failed to cp '$f'"
  sed "s,@prefix@,$prefix,g" "$f.tmp" >"$f" || abort "Failed to sed '$f.tmp'"
  rm -f "$f.tmp"
  echo ' [ OK ]'
done

echo '>>> Relocating hook scripts'
for f in : `find . -type f -name '*.bin'`; do
  test x"$f" = x: && continue
  p=${f%%.bin}
  test -f "$p" || continue
  echo -n "    $p"
  cp "$p" "$p.tmp" || abort "Failed to cp '$p'"
  sed "s,@XTC_REPOSITORY@,$prefix/$DEFAULT_XTC_REPOS," "$p.tmp" >"$p"
  rm -f "$p.tmp"
  echo ' [ OK ]'
done

echo ">>> Installing files under '$prefix'"
cp -r -p -f */ "$prefix" || abort 'Install failed'

uninstall="$prefix/bin/uninstall-xrm.sh"
echo -n ">>> Generating uninstall script in $uninstall"
echo '#! /bin/sh -x' >"$uninstall" \
  || abort 'Failed to create uninstall script'
find ./*/ -type f >>"$uninstall" || abort 'Failed to find files'
echo "./bin/uninstall-xrm.sh" >>"$uninstall" \
  || abort 'Failed to complete files'
cp "$uninstall" "$uninstall.tmp" || abort 'Failed to cp uninstall script'
sed "s,^\.,rm -f $prefix," "$uninstall.tmp" >"$uninstall" \
  || abort 'Failed to generate uninstall script for files'
find . -type d | sort -r >>"$uninstall" || abort 'Failed to find directories'
cp "$uninstall" "$uninstall.tmp" || abort 'Failed to cp uninstall script'
sed "s,^\.,rmdir $prefix," "$uninstall.tmp" >"$uninstall" \
  || abort 'Failed to generate uninstall script for directories'
rm -f "$uninstall.tmp"
chmod a+x "$uninstall" || abort 'Failed to make uninstall script executable'
echo ' [ OK ]'
